import * as THREE from "three";

export const autoScale = (geometry: THREE.BufferGeometry) => {
  // 计算模型的边界
  geometry.computeBoundingBox();
  // 获取模型的大小
  const modelSize = geometry.boundingBox!.getSize(new THREE.Vector3());
  const maxSize = Math.max(modelSize.x, modelSize.y, modelSize.z);
  // 根据模型的大小设置一个缩放因子
  const scaleFactor = 2 / maxSize; // 假设我们希望模型最大为2单位
  return scaleFactor;
};

export const getTriangleVertexs = (geometry: THREE.BufferGeometry) => {
  console.time("计算三角面面片顶点");
  const positions = geometry.attributes.position;
  const triangles = [];

  if (geometry.index) {
    const indices = geometry.index.array;

    for (let i = 0; i < indices.length; i += 3) {
      const triangleVertices = [
        new THREE.Vector3(
          positions.getX(indices[i]),
          positions.getY(indices[i]),
          positions.getZ(indices[i])
        ),
        new THREE.Vector3(
          positions.getX(indices[i + 1]),
          positions.getY(indices[i + 1]),
          positions.getZ(indices[i + 1])
        ),
        new THREE.Vector3(
          positions.getX(indices[i + 2]),
          positions.getY(indices[i + 2]),
          positions.getZ(indices[i + 2])
        ),
      ];

      triangles.push(triangleVertices);
    }
  } else {
    for (let i = 0; i < positions.count; i += 3) {
      const triangleVertices = [
        new THREE.Vector3(
          positions.getX(i),
          positions.getY(i),
          positions.getZ(i)
        ),
        new THREE.Vector3(
          positions.getX(i + 1),
          positions.getY(i + 1),
          positions.getZ(i + 1)
        ),
        new THREE.Vector3(
          positions.getX(i + 2),
          positions.getY(i + 2),
          positions.getZ(i + 2)
        ),
      ];

      triangles.push(triangleVertices);
    }
  }
  console.timeEnd("计算三角面面片顶点");
  return triangles;
};
